@@ -437,6 +437,9 @@ static GEnumValue transition_types[] = {
   {GES_VIDEO_STANDARD_TRANSITION_TYPE_CROSSFADE,
         "GES_VIDEO_STANDARD_TRANSITION_TYPE_CROSSFADE",
       "crossfade"},
+  {GES_VIDEO_STANDARD_TRANSITION_TYPE_FADE_IN,
+        "GES_VIDEO_STANDARD_TRANSITION_TYPE_FADE_IN",
+      "fade-in"},
   {0, NULL, NULL}
 };
 
@@ -605,3 +608,26 @@ ges_meta_flag_get_type (void)
   g_once (&once, (GThreadFunc) register_ges_meta_flag, &id);
   return id;
 }
+
+static void
+register_ges_marker_flags (GType * id)
+{
+  static const GFlagsValue values[] = {
+    {C_ENUM (GES_MARKER_FLAG_NONE), "GES_MARKER_FLAG_NONE", "none"},
+    {C_ENUM (GES_MARKER_FLAG_SNAPPABLE), "GES_MARKER_FLAG_SNAPPABLE",
+        "snappable"},
+    {0, NULL, NULL}
+  };
+
+  *id = g_flags_register_static ("GESMarkerFlags", values);
+}
+
+GType
+ges_marker_flags_get_type (void)
+{
+  static GType id;
+  static GOnce once = G_ONCE_INIT;
+
+  g_once (&once, (GThreadFunc) register_ges_marker_flags, &id);
+  return id;
+}
