@@ -849,14 +849,14 @@ _link_track (GESPipeline * self, GESTrack * track)
 
     /* Request a sinkpad from playsink */
     if (G_UNLIKELY (!(sinkpad =
-                gst_element_get_request_pad (self->priv->playsink,
+                gst_element_request_pad_simple (self->priv->playsink,
                     sinkpad_name)))) {
       GST_ELEMENT_ERROR (self, CORE, NEGOTIATION,
           (NULL), ("Could not get a pad from playsink for %s", sinkpad_name));
       goto error;
     }
 
-    tmppad = gst_element_get_request_pad (chain->tee, "src_%u");
+    tmppad = gst_element_request_pad_simple (chain->tee, "src_%u");
     lret = gst_pad_link_full (tmppad, sinkpad, GST_PAD_LINK_CHECK_NOTHING);
     if (G_UNLIKELY (lret != GST_PAD_LINK_OK)) {
       gst_object_unref (tmppad);
@@ -912,7 +912,7 @@ _link_track (GESPipeline * self, GESTrack * track)
       GST_INFO_OBJECT (track, "Linked to %" GST_PTR_FORMAT, sinkpad);
     }
 
-    tmppad = gst_element_get_request_pad (chain->tee, "src_%u");
+    tmppad = gst_element_request_pad_simple (chain->tee, "src_%u");
     if (G_UNLIKELY (gst_pad_link_full (tmppad, chain->encodebinpad,
                 GST_PAD_LINK_CHECK_NOTHING) != GST_PAD_LINK_OK)) {
       GST_ERROR_OBJECT (self, "Couldn't link track pad to encodebin");
@@ -987,7 +987,7 @@ _unlink_track (GESPipeline * self, GESTrack * track)
 /**
  * ges_pipeline_set_timeline:
  * @pipeline: A #GESPipeline
- * @timeline: (transfer full): The timeline to set for @pipeline
+ * @timeline: (transfer floating): The timeline to set for @pipeline
  *
  * Takes the given timeline and sets it as the #GESPipeline:timeline for
  * the pipeline.
@@ -1228,6 +1228,7 @@ ges_pipeline_set_mode (GESPipeline * pipeline, GESPipelineFlags mode)
 
     /* Disable render bin */
     GST_DEBUG ("Disabling rendering bin");
+    ges_timeline_thaw_commit (pipeline->priv->timeline);
     gst_object_ref (pipeline->priv->encodebin);
     gst_object_ref (pipeline->priv->urisink);
     gst_bin_remove_many (GST_BIN_CAST (pipeline),
@@ -1249,7 +1250,8 @@ ges_pipeline_set_mode (GESPipeline * pipeline, GESPipelineFlags mode)
       (mode & (GES_PIPELINE_MODE_RENDER | GES_PIPELINE_MODE_SMART_RENDER))) {
     /* Adding render bin */
     GST_DEBUG ("Adding render bin");
-
+    /* in render mode the commit needs to be locked, see #136 */
+    ges_timeline_freeze_commit (pipeline->priv->timeline);
     if (G_UNLIKELY (pipeline->priv->urisink == NULL)) {
       GST_ERROR_OBJECT (pipeline, "Output URI not set !");
       return FALSE;
@@ -1297,7 +1299,7 @@ ges_pipeline_set_mode (GESPipeline * pipeline, GESPipelineFlags mode)
  * the image is used. You can retrieve these caps from the returned sample
  * with gst_sample_get_caps().
  *
- * Returns: (transfer full): A sample of @self's current image preview in
+ * Returns: (transfer full) (nullable): A sample of @self's current image preview in
  * the format given by @caps, or %NULL if an error prevented fetching the
  * sample.
  */
@@ -1329,8 +1331,7 @@ ges_pipeline_get_thumbnail (GESPipeline * self, GstCaps * caps)
  * native size
  * @format: The desired mime type (for example, "image/jpeg")
  * @location: The path to save the thumbnail to
- * @error: (out) (allow-none) (transfer full): An error to be set in case
- * something goes wrong, or %NULL to ignore
+ * @error: An error to be set in case something goes wrong, or %NULL to ignore
  *
  * Saves the currently displayed image of the pipeline in preview to the
  * given location, in the specified dimensions and format.
@@ -1395,7 +1396,7 @@ ges_pipeline_save_thumbnail (GESPipeline * self, int width, int
  *
  * See ges_pipeline_get_thumbnail().
  *
- * Returns: (transfer full): A sample of @self's current image preview in
+ * Returns: (transfer full) (nullable): A sample of @self's current image preview in
  * the "RGB" format, scaled to @width and @height, or %NULL if an error
  * prevented fetching the sample.
  */
@@ -1429,7 +1430,7 @@ ges_pipeline_get_thumbnail_rgb24 (GESPipeline * self, gint width, gint height)
  *
  * Gets the #GESPipeline:video-sink of the pipeline.
  *
- * Returns: (transfer full): The video sink used by @self for preview.
+ * Returns: (transfer full) (nullable): The video sink used by @self for preview.
  */
 GstElement *
 ges_pipeline_preview_get_video_sink (GESPipeline * self)
@@ -1447,7 +1448,7 @@ ges_pipeline_preview_get_video_sink (GESPipeline * self)
 /**
  * ges_pipeline_preview_set_video_sink:
  * @self: A #GESPipeline in #GST_STATE_NULL
- * @sink: (transfer none): A video sink for @self to use for preview
+ * @sink: (transfer none) (nullable): A video sink for @self to use for preview
  *
  * Sets the #GESPipeline:video-sink of the pipeline.
  */
@@ -1466,7 +1467,7 @@ ges_pipeline_preview_set_video_sink (GESPipeline * self, GstElement * sink)
  *
  * Gets the #GESPipeline:audio-sink of the pipeline.
  *
- * Returns: (transfer full): The audio sink used by @self for preview.
+ * Returns: (transfer full) (nullable): The audio sink used by @self for preview.
  */
 GstElement *
 ges_pipeline_preview_get_audio_sink (GESPipeline * self)
@@ -1484,7 +1485,7 @@ ges_pipeline_preview_get_audio_sink (GESPipeline * self)
 /**
  * ges_pipeline_preview_set_audio_sink:
  * @self: A #GESPipeline in #GST_STATE_NULL
- * @sink: (transfer none): A audio sink for @self to use for preview
+ * @sink: (transfer none) (nullable): A audio sink for @self to use for preview
  *
  * Sets the #GESPipeline:audio-sink of the pipeline.
  */
