@@ -129,6 +129,7 @@ typedef struct _PadInfos
   GESSmartMixer *self;
   GstPad *mixer_pad;
   GstPad *ghostpad;
+  GstPad *real_mixer_pad;
 } PadInfos;
 
 static void
@@ -140,6 +141,7 @@ pad_infos_unref (PadInfos * infos)
       gst_element_release_request_pad (infos->self->mixer, infos->mixer_pad);
       gst_object_unref (infos->mixer_pad);
     }
+    gst_clear_object (&infos->real_mixer_pad);
 
     g_free (infos);
   }
@@ -190,7 +192,7 @@ ges_smart_mixer_get_mixer_pad (GESSmartMixer * self, GstPad ** mixerpad)
   PadInfos *info;
   GstPad *sinkpad;
 
-  sinkpad = gst_element_get_request_pad (GST_ELEMENT (self), "sink_%u");
+  sinkpad = gst_element_request_pad_simple (GST_ELEMENT (self), "sink_%u");
 
   if (sinkpad == NULL)
     return NULL;
@@ -239,6 +241,9 @@ set_pad_properties_from_positioner_meta (GstPad * mixer_pad, GstSample * sample,
 
   g_object_set (mixer_pad, "xpos", meta->posx, "ypos",
       meta->posy, "width", meta->width, "height", meta->height, NULL);
+
+  if (self->ABI.abi.has_operator)
+    g_object_set (mixer_pad, "operator", meta->operator, NULL);
 }
 
 /****************************************************
@@ -251,6 +256,7 @@ _request_new_pad (GstElement * element, GstPadTemplate * templ,
   PadInfos *infos = pad_infos_new ();
   GESSmartMixer *self = GES_SMART_MIXER (element);
   GstPad *ghost;
+  gchar *mixer_pad_name;
 
   infos->mixer_pad = gst_element_request_pad (self->mixer,
       gst_element_class_get_pad_template (GST_ELEMENT_GET_CLASS (self->mixer),
@@ -263,6 +269,19 @@ _request_new_pad (GstElement * element, GstPadTemplate * templ,
     return NULL;
   }
 
+  /* We can rely on this because the mixer bin uses the same name pad
+     as the internal mixer when creating the ghost pad. */
+  mixer_pad_name = gst_pad_get_name (infos->mixer_pad);
+  infos->real_mixer_pad = gst_element_get_static_pad (self->real_mixer,
+      mixer_pad_name);
+  g_free (mixer_pad_name);
+  if (infos->real_mixer_pad == NULL) {
+    GST_WARNING_OBJECT (element, "Could not get the real mixer pad");
+    pad_infos_unref (infos);
+
+    return NULL;
+  }
+
   infos->self = self;
 
   ghost = g_object_new (ges_smart_mixer_pad_get_type (), "name", name,
@@ -280,6 +299,8 @@ _request_new_pad (GstElement * element, GstPadTemplate * templ,
   g_hash_table_insert (self->pads_infos, ghost, infos);
   g_hash_table_insert (self->pads_infos, infos->mixer_pad,
       pad_infos_ref (infos));
+  g_hash_table_insert (self->pads_infos, infos->real_mixer_pad,
+      pad_infos_ref (infos));
   UNLOCK (self);
 
   GST_DEBUG_OBJECT (self, "Returning new pad %" GST_PTR_FORMAT, ghost);
@@ -320,6 +341,8 @@ _release_pad (GstElement * element, GstPad * pad)
   LOCK (element);
   g_hash_table_remove (GES_SMART_MIXER (element)->pads_infos, pad);
   g_hash_table_remove (GES_SMART_MIXER (element)->pads_infos, info->mixer_pad);
+  g_hash_table_remove (GES_SMART_MIXER (element)->pads_infos,
+      info->real_mixer_pad);
   peer = gst_pad_get_peer (pad);
   if (peer) {
     gst_pad_unlink (peer, pad);
@@ -382,6 +405,7 @@ ges_smart_mixer_dispose (GObject * object)
     g_hash_table_unref (self->pads_infos);
     self->pads_infos = NULL;
   }
+  gst_clear_object (&self->real_mixer);
 
   G_OBJECT_CLASS (ges_smart_mixer_parent_class)->dispose (object);
 }
@@ -401,15 +425,24 @@ ges_smart_mixer_constructed (GObject * obj)
 {
   GstPad *pad;
   GstElement *identity, *videoconvert;
-
   GESSmartMixer *self = GES_SMART_MIXER (obj);
   gchar *cname = g_strdup_printf ("%s-compositor", GST_OBJECT_NAME (self));
 
   self->mixer =
       gst_element_factory_create (ges_get_compositor_factory (), cname);
+  self->ABI.abi.has_operator =
+      gst_compositor_operator_get_type_and_default_value (NULL) != G_TYPE_NONE;
   g_free (cname);
-  g_object_set (self->mixer, "background", 1, "emit-signals", TRUE, NULL);
-  g_signal_connect (self->mixer, "samples-selected",
+
+  if (GST_IS_BIN (self->mixer)) {
+    g_object_get (self->mixer, "mixer", &self->real_mixer, NULL);
+    g_assert (self->real_mixer);
+  } else {
+    self->real_mixer = gst_object_ref (self->mixer);
+  }
+
+  g_object_set (self->real_mixer, "background", 1, "emit-signals", TRUE, NULL);
+  g_signal_connect (self->real_mixer, "samples-selected",
       G_CALLBACK (ges_smart_mixer_samples_selected_cb), self);
 
   /* See https://gitlab.freedesktop.org/gstreamer/gstreamer/issues/310 */
